try:
     from TMotorCANControl.TMotorManager import TMotorManager
except ModuleNotFoundError:
    from sys import path
    path.append("/home/pi/TMotorCANControl/src")
    from TMotorCANControl.TMotorManager import TMotorManager

# CHANGE THESE TO MATCH YOUR dev!
ID = 3
Type = 'AK80-9'

with TMotorManager(motor_type=Type, motor_ID=ID, CSV_file="log.csv") as dev:
    if dev.check_can_connection():
        print("\nmotor is successfully connected!\n")
    else:
        print("\nmotor not connected. Check dev power, network wiring, and CAN bus connection.\n")
    